@@ -83,7 +83,10 @@ check_command(char **command, int cnt)
 	    } else if (strncmp(command[1], TEXT_TMPL, LEN_TMPL) == 0) {
                 /* case template reload */
                 return_flag = TYPE_TMPRELOAD;
-	    }
+	    } else if (strncmp(command[1], TEXT_WHITELIST, LEN_WHITELIST) == 0) {
+                /* case template reload */
+                return_flag = TYPE_WHITELISTRELOAD;
+            }
 	}
     } else if (strncmp(command[0], TEXT_LOGIN, LEN_LOGIN) == 0) {
         /* case login */
@@ -253,6 +256,7 @@ accept_command(char *cfgfile, char *addr, int port)
 		        }
 		    }
 		    break;
+
 		case TYPE_TMPRELOAD:
 		    if (login_stat == ST_NOLOGIN) {
                         if (write(connected_socket, OUTPUT_ERROR_LOGIN, 
@@ -278,6 +282,33 @@ accept_command(char *cfgfile, char *addr, int port)
 		        }
 		    }
 		    break;
+
+		case TYPE_WHITELISTRELOAD:
+		    if (login_stat == ST_NOLOGIN) {
+                        if (write(connected_socket, OUTPUT_ERROR_LOGIN, 
+							LEN_OUTPUT_ERROR_LOGIN) == -1) {
+			    log(ERR_IO_WRITE, "accept_command", OUTPUT_NG);
+		        }
+			break;
+		    }
+		    cfg = config_init();
+                    /* reload template file */
+                    ret_reload = reload_whitelist(cfg->cf_whitelistpath);
+		    config_release(cfg);
+                    if (ret_reload == 0) {
+                        /* case reload successfull */
+			log(WHITELIST_RELOADING, "accept_command", cfg->cf_whitelistpath);
+                        if (write(connected_socket, OUTPUT_OK, LEN_OUTPUT_OK) == -1) {
+			    log(ERR_IO_WRITE, "accept_command", OUTPUT_NG);
+		        }
+                    } else {
+                        /* case reload fail */
+                        if (write(connected_socket, OUTPUT_NG, LEN_OUTPUT_NG) == -1) {
+			    log(ERR_IO_WRITE, "accept_command", OUTPUT_NG);
+		        }
+		    }
+		    break;
+
 		case TYPE_LOGIN:
 		    cfg = config_init();
 		    if (strncmp(arg_list[1], cfg->cf_commandpass, 
@@ -298,6 +329,16 @@ accept_command(char *cfgfile, char *addr, int port)
 		    break;
 	    }
 
+            /* START ADD 201503*/
+            arg_list_free(arg_list, cnt);
+            arg_list = NULL;
+
+            if (buf != NULL) {
+                free(buf);
+                buf = NULL;
+            }
+            /* END ADD 201503*/
+
 	    if (ret_command == TYPE_EXIT) {
 		break;
 	    }
