@@ -161,6 +161,18 @@
 #define ERR_REGEX		"%s: Regex error.(%s)"
 #define ERR_AUTOBCC		"%s: Cannot add RcptTo.(%s):"
 
+/* ADD(20170119)*/
+#define INVALID_CHAR	"%s: Invalid character in mail address."
+
+/* ADD(20170123)*/
+#define ERR_ERRTMPL_READ	"%s: Cannot read error message template file.(%s)"
+#define ERR_ERRTMPL_OPEN	"%s: Cannot open error message template file.(%s)"
+#define ERR_ERRTMPL_STAT	"%s: Cannot fstat error message template file.(%s)"
+#define ERRTMPL_NOSTRING	"%s: No strings in error message template file.(%s)"
+
+/* ADD(20170130)*/
+#define ERR_REPEAT_EXTENSION	"Same extension command is repeated. (MIME type: %s)"
+
 /* harmless */
 #define LOG_HARMLESS            "harmless: source=%s, message-id=%s, sender=%s, recipients=%s"
 
