@@ -33,8 +33,8 @@
 #define OTHERKEYWORD    "other"
 #define ATMARK 		'@'
 #define DOT    		'.'
-#define NOT_ENC   0
-#define ENC       1
+#define NOT_ENC   0    //NOT DELETE in delete mode.
+#define ENC       1    //DELETE in delete mode.
 
 #define ADDENCLIST_ERR	-1
 #define RECORD_FOUND	1
@@ -75,6 +75,7 @@ struct person {
 };
 
 int search_rcptaddr(struct config *, char *, struct rcptaddr *, struct rcptinfo **, struct rcptinfo **);
+int search_rcptaddr_delmode(struct config *, struct rcptaddr *, struct rcptinfo **, struct rcptinfo **);
 int add_enclist(struct rcptinfo ***, char *, char *, char *);
 int search_fromaddr_bdb(struct config *, char *);
 int search_subdomain_bdb(DB *, const char *, char *, char **, char **);
