@@ -873,14 +873,17 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 
     ct_object = g_mime_object_get_content_type(object);
 
-    if ((strncmp(ct_object->type, CONTENT_T_MULTIPART, LEN_CONTENT_T_MULTIPART) == 0) && 
-        ((strncmp(ct_object->subtype, CONTENT_SUBT_RELATED, LEN_CONTENT_SUBT_RELATED) == 0) ||
-         (strncmp(ct_object->subtype, CONTENT_SUBT_ALTERNATIVE, LEN_CONTENT_SUBT_ALTERNATIVE) == 0))) {
+    /* default policy set */
+    if ((cfg->cf_alternativepartencrypt[0] == 'N') || (cfg->cf_alternativepartencrypt[0] == 'n')) {
+        if ((strncmp(ct_object->type, CONTENT_T_MULTIPART, LEN_CONTENT_T_MULTIPART) == 0) && 
+            ((strncmp(ct_object->subtype, CONTENT_SUBT_RELATED, LEN_CONTENT_SUBT_RELATED) == 0) ||
+             (strncmp(ct_object->subtype, CONTENT_SUBT_ALTERNATIVE, LEN_CONTENT_SUBT_ALTERNATIVE) == 0))) {
 #ifndef GMIME24
-        g_object_unref (object);
+            g_object_unref (object);
 #endif
-	pthread_mutex_unlock(&gmime_lock);
-	return(PM_NO_ATTACHFILE);
+    	    pthread_mutex_unlock(&gmime_lock);
+	    return(PM_NO_ATTACHFILE);
+        }
     }
 
     /* make zip directory */
@@ -940,7 +943,7 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     /* Not attach file */
     if (mz->namelist == NULL) {
 	pthread_mutex_unlock(&gmime_lock);
-        return(PM_NO_MULTIPART);
+        return(PM_NO_ATTACHFILE);
     }
 
     pthread_mutex_unlock(&gmime_lock);
